===========
ionosphere
===========

.. image:: https://img.shields.io/pypi/l/troposphere.svg
    :target: https://opensource.org/licenses/BSD-2-Clause


About
=====

ionosphere - library to create `Azure Resource Manager templates`_ descriptions (ionosphere is porting of troposphere)

The ionosphere library allows for easier creation of the Azure Resource Manager templates
JSON by writing Python code to describe the Azure resources. 

To facilitate catching ARM templates or JSON errors early the library has
property and type checking built into the classes.

Currently supported Azure resource types
======================================

- TBD



Licensing
=========

troposphere is licensed under the `BSD 2-Clause license`_.
See `LICENSE`_ for the troposphere full license text.


.. _`Azure Resource Manager templates`: https://docs.microsoft.com/en-us/azure/templates/
.. _`LICENSE`: https://github.com/cloudtools/troposphere/blob/master/LICENSE
.. _`BSD 2-Clause license`: http://opensource.org/licenses/BSD-2-Clause
